<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       http://ays-pro.com/
 * @since      1.0.0
 *
 * @package    Ays_Pb
 * @subpackage Ays_Pb/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Ays_Pb
 * @subpackage Ays_Pb/public
 * @author     AYS Pro LLC <info@ays-pro.com>
 */
class Ays_Pb_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Ays_Pb_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Ays_Pb_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
        wp_enqueue_style( 'font-awesome', '//use.fontawesome.com/releases/v5.0.13/css/all.css', array(), $this->version, 'all' );
		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/ays-pb-public.css', array(), $this->version, 'all' );
		wp_enqueue_style( 'pb_animate', plugin_dir_url( __FILE__ ) . 'css/animate.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Ays_Pb_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Ays_Pb_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/ays-pb-public.js', array( 'jquery' ), $this->version, false );
	}
	

	public function ays_generate_shortcode(){
        add_shortcode( 'ays_pb', array($this, 'ays_generate_popup') );
    }
	
	public function ays_set_cookie($attr){
		
        $cookie_time = $attr['cookie'];
        $cookie_name = 'ays_popup_cookie_'.$attr['id'];
        $cookie_value = $attr['title'];
        $cookie_expiration =  time() + ($cookie_time * 60);
        setcookie($cookie_name, $cookie_value, $cookie_expiration, '/');
    }
	

	public function ays_generate_popup( $attr ){

        $id = ( isset($attr['id']) ) ? absint( intval( $attr['id'] ) ) : null;
		$popupbox = $this->get_pb_by_id($id);
        $ays_popup_on = $popupbox['onoffswitch'];

		if (isset($popupbox['log_user']) && isset($popupbox['guest'])){
            if ( is_user_logged_in() && $popupbox['log_user'] != "On" || $popupbox['guest'] !='On' && $popupbox['log_user'] != "On") {
                $popupbox['onoffswitch'] = 'Off';
            }
            elseif (!is_user_logged_in() && $popupbox['log_user'] == "On"){
                if ($popupbox['guest'] !='On') {
                    $popupbox['onoffswitch'] = 'Off';
                }
            }
        }
		if (isset($popupbox['active_date_check']) && $popupbox['active_date_check'] == "on"){
            if (isset($popupbox['activeInterval']) && isset($popupbox['deactiveInterval'])) {
                $startDate = strtotime($popupbox['activeInterval']);
                $endDate = strtotime($popupbox['deactiveInterval']);
                if ($startDate > strtotime(date("Y-m-d")) || $endDate < strtotime(date("Y-m-d"))) {
                    $popupbox['onoffswitch'] = 'Off';
                }
                else{
                    $popupbox['onoffswitch'] = $ays_popup_on;
                }
            }
        }

        if(isset($popupbox['onoffswitch']) && $popupbox['onoffswitch'] == 'On'){


			
			if(!isset($_COOKIE['ays_popup_cookie_'.$id])){
				$this->ays_set_cookie($popupbox);
			}else{
				return;
			}
            
			$ays_pb_shortcode               = $popupbox["shortcode"];            
            $width = ( isset($attr['w']) ) ? absint( intval( $attr['w'] ) ) : $popupbox["width"];
            $height = ( isset($attr['h']) ) ? absint( intval( $attr['h'] ) ) : $popupbox["height"];
			$popupbox["width"] = $width;
			$popupbox["height"] = $height;
            $show_title                     = $popupbox["show_popup_title"];
            $show_desc                      = $popupbox["show_popup_desc"];
            $closeButton                    = $popupbox["close_button"];
			$ays_pb_autoclose               = $popupbox["autoclose"];
			$ays_pb_title           		= $popupbox["title"];
			$ays_pb_description     		= $popupbox["description"];
			$ays_pb_bgcolor					= $popupbox["bgcolor"];
			$ays_pb_header_bgcolor		    = $popupbox["header_bgcolor"];
			$ays_pb_custom_css              = $popupbox["custom_css"];
			$ays_pb_animate_in              = $popupbox["animate_in"];
			$ays_pb_animate_out             = $popupbox["animate_out"];
			$ays_pb_template                = ($popupbox["view_type"] == false || $popupbox["view_type"] == '') ? 'default' : $popupbox["view_type"];
			$ays_pb_custom_css              = $popupbox["custom_css"];
			$ays_pb_custom_html             = $popupbox["custom_html"];
			$popupbox["delay"]              = ($popupbox["delay"] == false) ? 0 : $popupbox["delay"];
			$popupbox["scroll_top"]         = ($popupbox["scroll_top"] == false) ? 0 : $popupbox["scroll_top"];
			$ays_pb_show_all                = $popupbox["show_all"];
			$ays_pb_action_buttons          = ($popupbox["action_button"] == false || $popupbox["action_button"] == '') ? "" : $popupbox["action_button"] ;
			$ays_pb_action_buttons_type     = ($popupbox["action_button_type"] == false) ? "both" : $popupbox["action_button_type"];
			$ays_pb_modal_content           = ($popupbox["modal_content"] == false) ? "shortcode" : $popupbox["modal_content"];
			$ays_pb_delay = intval($popupbox["delay"]);
			$ays_pb_scroll_top = intval($popupbox["scroll_top"]);
			
			$ays_pb_textcolor = (!isset($popupbox["textcolor"])) ? "#000000" : $popupbox["textcolor"];
			$ays_pb_bordersize = (!isset($popupbox["bordersize"])) ? 0 : $popupbox["bordersize"];
			$ays_pb_bordercolor = (!isset($popupbox["bordercolor"])) ? "#000000" : $popupbox["bordercolor"];
			$ays_pb_border_radius = (!isset($popupbox["border_radius"])) ? "4" : $popupbox["border_radius"];
            $modal_class = 'ays-pb-modal';
            if($ays_pb_action_buttons_type == 'both' || $ays_pb_action_buttons_type == 'pageLoaded'){
               if($ays_pb_delay == 0 && $ays_pb_scroll_top == 0){
                    $open = "checked";
                    $ays_pb_animate_in_open = $ays_pb_animate_in;
                }else{ 
                    $open = "";
                    $ays_pb_animate_in_open = "";
                } 
            }

            if($ays_pb_action_buttons_type == 'clickSelector'){
                $ays_pb_animate_in_open = $ays_pb_animate_in;
                $open = "";
            }
            if($ays_pb_title != ''){
                $ays_pb_title = "<h2 style='color: $ays_pb_textcolor !important;'>$ays_pb_title</h2>";
            }
            if($ays_pb_description != ''){
                $ays_pb_description = "<p>$ays_pb_description</p>";
            }
            if($ays_pb_custom_css != '' || $ays_pb_custom_css != null){
                $ays_pb_custom_css = "<style>$ays_pb_custom_css</style>";
            }

    // Tigran
        global $wp_roles;
        $user = wp_get_current_user();
        $users_roles  = $wp_roles->role_names;
        $users_role = (isset($popupbox['users_role']) && $popupbox['users_role'] != '') ? $popupbox['users_role'] : '';
        $users_role = json_decode($users_role);
        if(!empty($users_role)){
            if (is_array($users_role)) {
                foreach($users_role as $key => $role){
                    if(in_array($role, $users_roles)){
                        $users_role[$key] = array_search($role, $users_roles);
                    }                        
                }
            }else{
                if(in_array($users_role, $users_roles)){
                    $users_role = array_search($users_role, $users_roles);
                }
            }
            $is_user_role = false;
            if(is_array($users_role)){
                foreach($users_role as $role){                        
                    if (in_array(strtolower($role), (array)$user->roles)) {
                        $is_user_role = true;
                        break;
                    }
                }                    
            }else{
                if (in_array(strtolower($users_role), (array)$user->roles)) {
                    $is_user_role = true;
                }
            }

            if (!$is_user_role) {
                $popupbox['onoffswitch'] = 'Off';
            }
        }else{
            $popupbox['onoffswitch'] = 'On';
        }
    //Tigran

            
            $ays_pb_bgcolor_rgba = $this->hex2rgba($ays_pb_bgcolor, 0.85);
            
			$popupbox_view = $ays_pb_custom_css."
					<div class='ays-pb-modals av_pop_modals_".$id."' style='min-width: 100%;'>
                        <input type='hidden' value='".$ays_pb_animate_in."' id='ays_pb_modal_animate_in_".$id."'>
                        <input type='hidden' value='".$ays_pb_animate_out."' id='ays_pb_modal_animate_out_".$id."'>
						<input id='ays-pb-modal-checkbox_".$id."' class='ays-pb-modal-check' type='checkbox' $open/>";
            switch($ays_pb_template){
                case 'mac':
                    include_once( 'partials/ays-pb-public-templates.php' );
                    $mac_template =  new Ays_Pb_Public_Templates($this->plugin_name, $this->version);
                    $popupbox_view .= $mac_template->ays_pb_template_macos($popupbox);
                    $modal_class = 'ays_window';
                    $modal_close_additional_js = "";
                    break;
                case 'cmd':
                    include_once( 'partials/ays-pb-public-templates.php' );
                    $cmd_template =  new Ays_Pb_Public_Templates($this->plugin_name, $this->version);
                    $popupbox_view .= $cmd_template->ays_pb_template_cmd($popupbox);
                    $modal_class = 'ays_window';
                    $modal_close_additional_js = "$(document).find('.ays-pb-modal_".$id."').css('top', 'unset');";
                    break;
                case 'ubuntu':
                    include_once( 'partials/ays-pb-public-templates.php' );
                    $ubuntu_template =  new Ays_Pb_Public_Templates($this->plugin_name, $this->version);
                    $popupbox_view .= $ubuntu_template->ays_pb_template_ubuntu($popupbox);
                    $modal_class = 'ays_ubuntu_window';
                    $modal_close_additional_js = "$(document).find('.ays-pb-modal_".$id."').css('top', 'unset');";
                    break;
                case 'winXP':
                    include_once( 'partials/ays-pb-public-templates.php' );
                    $winxp_template =  new Ays_Pb_Public_Templates($this->plugin_name, $this->version);
                    $popupbox_view .= $winxp_template->ays_pb_template_winxp($popupbox);
                    $modal_class = 'ays_winxp_window';
                    $modal_close_additional_js = "$(document).find('.ays-pb-modal_".$id."').css('top', 'unset');";
                    break;
                case 'win98':
                    include_once( 'partials/ays-pb-public-templates.php' );
                    $win98_template =  new Ays_Pb_Public_Templates($this->plugin_name, $this->version);
                    $popupbox_view .= $win98_template->ays_pb_template_win98($popupbox);
                    $modal_class = 'ays_win98_window';
                    $modal_close_additional_js = "";
                    break;
                case 'lil':
                    include_once( 'partials/ays-pb-public-templates.php' );
                    $lil_template =  new Ays_Pb_Public_Templates($this->plugin_name, $this->version);
                    $popupbox_view .= $lil_template->ays_pb_template_lil($popupbox);
                    $modal_class = 'ays_lil_window';
                    $modal_close_additional_js = "";
                    break;
                case 'image':
                    include_once( 'partials/ays-pb-public-templates.php' );
                    $lil_template =  new Ays_Pb_Public_Templates($this->plugin_name, $this->version);
                    $popupbox_view .= $lil_template->ays_pb_template_image($popupbox);
                    $modal_class = 'ays_image_window';
                    $modal_close_additional_js = "";
                    break;
                    case 'template':
                    include_once( 'partials/ays-pb-public-templates.php' );
                    $lil_template =  new Ays_Pb_Public_Templates($this->plugin_name, $this->version);
                    $popupbox_view .= $lil_template->ays_pb_template_template($popupbox);
                    $modal_class = 'ays_image_window';
                    $modal_close_additional_js = "";
                    break;
                default:
                    include_once( 'partials/ays-pb-public-templates.php' );
                    $default_template =  new Ays_Pb_Public_Templates($this->plugin_name, $this->version);
                    $popupbox_view .= $default_template->ays_pb_template_default($popupbox);
                    $modal_close_additional_js = "";
                    break;
            }
            
            $popupbox_view .= "<div id='ays-pb-screen-shade_".$id."' overlay='overlay_".$id."'></div>
                        <input type='hidden' class='ays_pb_delay_".$id."' value='".$ays_pb_delay."'/>
                        <input type='hidden' class='ays_pb_scroll_".$id."' value='".$ays_pb_scroll_top."'/>
                        <input type='hidden' class='ays_pb_abt_".$id."' value='".$ays_pb_action_buttons_type."'/>
					</div>                   
                    <style>
                        .ays-pb-modal_".$id.", .av_pop_modals_".$id." {
                            display:none;
                        }
                        .ays-pb-modal-check:checked ~ #ays-pb-screen-shade_".$id." {
                            opacity: 0.5;
                            pointer-events: auto;
                        }
                        
                        .ays_cmd_window {                            
                            background-color: ".$ays_pb_bgcolor_rgba.";
                            border: 1px solid #c9c9c9 !important;
                        }
                        
                        .ays_cmd_window-cursor .ays_cmd_i-cursor-underscore {
                            background-color: black;
                        }
                        
                        .ays_cmd_window-cursor .ays_cmd_i-cursor-indicator {
                            background-color: transparent;
                        }
                        
                        #ays-pb-screen-shade_".$id." {
                            opacity: 0;
                            background: #000;
                            position: absolute;
                            left: 0;
                            right: 0;
                            top: 0;
                            bottom: 0;
                            pointer-events: none;
                            transition: opacity 0.8s;
                        }
                    </style>
                    ";


            if($ays_pb_action_buttons_type != 'clickSelector'){
                $popupbox_view .= "
                    <script>
                    (function( $ ) {
	                    'use strict';
                        $(document).ready(function(){
                            $(document).find('.ays-pb-modals').appendTo($(document.body));
                            let ays_pb_scrollTop_".$id." = parseInt($(document).find('.ays_pb_scroll_".$id."').val()),
                                ays_pb_delayOpen_".$id." = parseInt($(document).find('.ays_pb_delay_".$id."').val()),
                                time_pb_".$id." = $(document).find('.ays_pb_timer_".$id." span').data('seconds'),
                                ays_pb_effectIn_".$id." = $(document).find('#ays_pb_modal_animate_in_".$id."').val();
                            if( ays_pb_delayOpen_".$id." == 0 &&  ays_pb_scrollTop_".$id." == 0){
                                $(document).find('.av_pop_modals_".$id."').css('display','block');
                            }
                            if(time_pb_".$id." !== undefined){
                                if(time_pb_".$id." !== 0){
                                    $(document).find('#ays-pb-modal-checkbox_".$id."').trigger('click');
                                    let timer_pb_".$id." = setInterval(function(){
                                        let newTime_pb_".$id." = time_pb_".$id."--;
                                        let ays_pb_effectOut_".$id." = $(document).find('#ays_pb_modal_animate_out_".$id."').val();
                                        $(document).find('.ays_pb_timer_".$id." span').text(newTime_pb_".$id.");
                                        if(newTime_pb_".$id." <= 0){
                                            $(document).find('.ays-pb-modal-close_".$id."').trigger('click');
                                            $(document).find('.ays-pb-modal_".$id."').attr('class', '".$modal_class." ays-pb-modal_".$id." '+ays_pb_effectOut_".$id.");
                                            setTimeout(function(){ $(document).find('.ays-pb-modal_".$id."').css('display', 'none');}, 500);
                                            $modal_close_additional_js
                                            clearInterval(timer_pb_".$id.");
                                        }
                                        $(document).find('.ays-pb-modal-close_".$id."').on('click', function(){                                        
                                            $(document).find('.av_pop_modals_".$id."').css('pointer-events', 'none');
                                            $(document).find('.ays-pb-modal_".$id."').attr('class', '".$modal_class." ays-pb-modal_".$id." '+ays_pb_effectOut_".$id.");
                                            setTimeout(function(){
                                                $(document).find('.ays-pb-modal_".$id."').css('display', 'none');
                                                $(document).find('.av_pop_modals_".$id."').css('display', 'none');
                                            }, 400);  
                                            $modal_close_additional_js
                                            setTimeout(function(){ $(document).find('#ays-pb-screen-shade_".$id."').css({'opacity': '0', 'display': 'none'}); }, 500);
                                            clearInterval(timer_pb_".$id.");
                                        });
                                    },1000); 
                                } else {
                                     $(document).find('.ays_pb_timer_".$id."').css('display','none');
                                     $(document).find('.ays-pb-modal-close_".$id."').on('click', function(){  
                                        let ays_pb_effectOut_".$id." = $(document).find('#ays_pb_modal_animate_out_".$id."').val();                                      
                                        $(document).find('.av_pop_modals_".$id."').css('pointer-events', 'none');
                                        $(document).find('.ays-pb-modal_".$id."').attr('class', '".$modal_class." ays-pb-modal_".$id." '+ays_pb_effectOut_".$id.");
                                        setTimeout(function(){
                                            $(document).find('.ays-pb-modal_".$id."').css('display', 'none');
                                            $(document).find('.av_pop_modals_".$id."').css('display', 'none');
                                        }, 400);  
                                        $modal_close_additional_js
                                        setTimeout(function(){ $(document).find('#ays-pb-screen-shade_".$id."').css({'opacity': '0', 'display': 'none'}); }, 500);
                                     });
                                }
                            }
                            let count = 0;
                            if( ays_pb_scrollTop_".$id." !== 0 ){
                                $(window).scroll(function() {
                                    if(($(this).scrollTop() >= ays_pb_scrollTop_".$id.") && (count === 0)) {
                                        count++;
                                        if( ays_pb_delayOpen_".$id." !== 0 ){                        
                                            $(document).find('.ays-pb-modal_".$id."').css('animation-delay', ays_pb_delayOpen_".$id."/1000);
                                            setTimeout(function(){
                                                $(document).find('.av_pop_modals_".$id."').css('display','block');
                                                $(document).find('.ays-pb-modal_".$id."').addClass(ays_pb_effectIn_".$id.");
                                                $(document).find('.ays-pb-modal_".$id."').css('display', 'block');
                                                $(document).find('#ays-pb-screen-shade_".$id."').css({'opacity': '0.5'});
                                                $(document).find('.ays-pb-modal-check_".$id."').prop('checked', true);
                                            }, ays_pb_delayOpen_".$id.");
                                        }else{
                                            $(document).find('.av_pop_modals_".$id."').css('display','block');
                                            $(document).find('.ays-pb-modal_".$id."').addClass(ays_pb_effectIn_".$id.");
                                            $(document).find('.ays-pb-modal_".$id."').css('display', 'block');
                                            $(document).find('#ays-pb-screen-shade_".$id."').css({'opacity': '0.5'});
                                            $(document).find('.ays-pb-modal-check_".$id."').prop('checked', true);
                                        }
                                    }
                                });
                            }else{
                                if( ays_pb_delayOpen_".$id." !== 0 ){
                                    $(document).find('.ays-pb-modal_".$id."').css('animation-delay', ays_pb_delayOpen_".$id."/1000);
                                    setTimeout(function(){
                                        $(document).find('.av_pop_modals_".$id."').css('display','block');
                                        $(document).find('.ays-pb-modal_".$id."').addClass(ays_pb_effectIn_".$id.");
                                        $(document).find('.ays-pb-modal_".$id."').css('display', 'block');
                                        $(document).find('#ays-pb-screen-shade_".$id."').css({'opacity': '0.5'});
                                        $(document).find('.ays-pb-modal-check_".$id."').attr('checked', 'checked');
                                    }, ays_pb_delayOpen_".$id.");
                                } else {
                                    if($(document).find('.ays_pb_abt_".$id."').val() != 'clickSelector'){
                                        $(document).find('.av_pop_modals_".$id."').css('display','block');
                                        $(document).find('.ays-pb-modal_".$id."').addClass(ays_pb_effectIn_".$id.");
                                        $(document).find('.ays-pb-modal_".$id."').css('display', 'block');
                                        $(document).find('#ays-pb-screen-shade_".$id."').css({'opacity': '0.5'});
                                        $(document).find('.ays-pb-modal-check_".$id."').attr('checked', 'checked');
                                    }
                                }
                            }
                            if ('".$popupbox['onoffoverlay']."' != 'On'){
                                $(document).find('#ays-pb-screen-shade_".$id."').css({'opacity': '0', 'display': 'none !important', 'pointer-events': 'none', 'background': 'none'});
                                $(document).find('.ays-pb-modal_".$id."').css('pointer-events', 'auto');
                                $(document).find('.av_pop_modals_".$id."').css('pointer-events','none');
                            };
                        });
                    })( jQuery );
                </script>";
            }
            if($ays_pb_action_buttons_type != 'pageLoaded'){
                $popupbox_view .= "                
                    <script>
                        (function( $ ) {
                            'use strict';
                        $(document).ready(function(){       
                            $(document).find('".$ays_pb_action_buttons."').on('click', function(){
                                $(document).find('.av_pop_modals_".$id."').css('display','block');
                                $(document).find('.av_pop_modals_".$id."').css('pointer-events', 'auto');
                                $(document).find('.ays_pb_timer_".$id." span').html($(document).find('.ays_pb_timer_".$id." span').attr('data-seconds'));
                                clearInterval(timer_pb_".$id.");
                                timer_pb_".$id." = null;
                                $(document).find('.ays-pb-modal_".$id."').removeClass($(document).find('#ays_pb_modal_animate_out_".$id."').val());
                                $(document).find('.ays-pb-modal_".$id."').addClass($(document).find('#ays_pb_modal_animate_in_".$id."').val());
                                $(document).find('.ays-pb-modal_".$id."').css('display', 'block');
                                $(document).find('#ays-pb-screen-shade_".$id."').css({'opacity': '0.5', 'display': 'block'});
                                $(document).find('.ays-pb-modal-check_".$id."').prop('checked', true);
                                $(document).find('.ays-pb-modal-check_".$id."').attr('checked', true);
                                $(document).find('#ays-pb-modal-checkbox_".$id."').trigger('click');
                                var time_pb_".$id." = $(document).find('.ays_pb_timer_".$id." span').data('seconds');
                                if(time_pb_".$id." !== undefined){ 
                                 if(time_pb_".$id." !== 0){
                                    var timer_pb_".$id." = setInterval(function(){
                                        let newTime_pb_".$id." = time_pb_".$id."--;
                                        let ays_pb_effectOut_".$id." = $(document).find('#ays_pb_modal_animate_out_".$id."').val();
                                        $(document).find('.ays_pb_timer_".$id." span').text(newTime_pb_".$id.");
                                        if(newTime_pb_".$id." <= 0){
                                            $(document).find('.ays-pb-modal-close_".$id."').trigger('click');
                                            $(document).find('.ays-pb-modal_".$id."').attr('class', '".$modal_class." ays-pb-modal_".$id." '+$(document).find('#ays_pb_modal_animate_out_".$id."').val());
                                            $modal_close_additional_js
                                            setTimeout(function(){ $(document).find('.ays-pb-modal_".$id."').css('display', 'none');}, 500);
                                            clearInterval(timer_pb_".$id.");
                                        }
                                        $(document).find('.ays-pb-modal-close_".$id."').on('click', function(){
                                        $(document).find('.av_pop_modals_".$id."').css('pointer-events', 'none');
                                            $(document).find('.ays-pb-modal_".$id."').attr('class', '".$modal_class." ays-pb-modal_".$id." '+ays_pb_effectOut_".$id.");
                                            $modal_close_additional_js
                                            setTimeout(function(){ $(document).find('.ays-pb-modal_".$id."').css('display', 'none'); }, 400);  
                                            setTimeout(function(){ $(document).find('#ays-pb-screen-shade_".$id."').css({'opacity': '0', 'display': 'none'}); }, 500);
                                            clearInterval(timer_pb_".$id.");
                                        });
                                    }, 1000);
                                    
                                 } else {
                                     $(document).find('.ays_pb_timer_".$id."').css('display','none');
                                     $(document).find('.ays-pb-modal-close_".$id."').on('click', function(){  
                                        let ays_pb_effectOut_".$id." = $(document).find('#ays_pb_modal_animate_out_".$id."').val();                                      
                                        $(document).find('.av_pop_modals_".$id."').css('pointer-events', 'none');
                                        $(document).find('.ays-pb-modal_".$id."').attr('class', '".$modal_class." ays-pb-modal_".$id." '+ays_pb_effectOut_".$id.");
                                        setTimeout(function(){
                                            $(document).find('.ays-pb-modal_".$id."').css('display', 'none');
                                            $(document).find('.av_pop_modals_".$id."').css('display', 'none');
                                        }, 400);  
                                        $modal_close_additional_js
                                        setTimeout(function(){ $(document).find('#ays-pb-screen-shade_".$id."').css({'opacity': '0', 'display': 'none'}); }, 500);
                                     });
                                 }
                                }
                                if ('".$popupbox['onoffoverlay']."' != 'On'){
                                    $(document).find('#ays-pb-screen-shade_".$id."').css({'opacity': '0', 'display': 'none !important', 'pointer-events': 'none'});
                                    $(document).find('.ays-pb-modal_".$id."').css('pointer-events', 'auto');
                                    $(document).find('.av_pop_modals_".$id."').css('pointer-events','none');
                                };
                            });
                            if ('".$popupbox['onoffoverlay']."' != 'On'){
                                $(document).find('#ays-pb-screen-shade_".$id."').css({'opacity': '0', 'display': 'none !important', 'pointer-events': 'none'});
                                $(document).find('.ays-pb-modal_".$id."').css('pointer-events', 'auto');
                                $(document).find('.av_pop_modals_".$id."').css('pointer-events','none');
                            };
                        });  
                    })( jQuery );
                </script>";
            }

            if ($popupbox['onoffoverlay'] != 'On'){
                $popupbox_view .= "<script>
                    jQuery(document).ready(function() {
                        jQuery(document).find('#ays-pb-screen-shade_".$id."').css({'opacity': '0', 'display': 'none !important', 'pointer-events': 'none'});
                        jQuery(document).find('.ays-pb-modal_".$id."').css('pointer-events', 'auto');
                        jQuery(document).find('.av_pop_modals_".$id."').css('pointer-events','none');
                    })
                </script>";
            }
            return $popupbox_view;
        }

    }


    public function ays_has_shortcode_in_posts($id){

	    if (isset(get_post()->post_content)) {
            $ays_has_shortcode = strpos(get_post()->post_content, '[ays_pb id=' . $id . '');
            if ($ays_has_shortcode !== false) {
                return true;
            }
        } else {
            return false;
        }
    }

    public function ays_shortcodes_show_all(){
        global $wpdb;
        $post_id = get_the_ID();
        $sql2 = "SELECT * FROM {$wpdb->prefix}ays_pb WHERE view_place <> '' ";
        $result2 = $wpdb->get_results($sql2, "ARRAY_A");
        if(!empty($result2)){
            foreach($result2 as $key => $i){
                $ays_fb_view_place  = explode( '***', $i["view_place"] );
                if(in_array($post_id, $ays_fb_view_place)){
                    $shortcode2 = "[ays_pb id={$i['id']} w={$i['width']} h={$i['height']} ]";
                    $ays_search_shortcode = $this->ays_has_shortcode_in_posts($i['id']);
                    if ($ays_search_shortcode !== true){
                        echo do_shortcode($shortcode2);
                    }
                }
            }
        }
        $sql = "SELECT * FROM {$wpdb->prefix}ays_pb WHERE show_all = 'yes'";
        $result = $wpdb->get_results($sql, "ARRAY_A");
        if(!empty($result)){
            foreach($result as $key => $i){
                $shortcode = "[ays_pb id={$i['id']} w={$i['width']} h={$i['height']} ]";
                $ays_search_shortcode = $this->ays_has_shortcode_in_posts($i['id']);
                if ($ays_search_shortcode !== true){
                    echo do_shortcode($shortcode);
                }
            }
        }
        
    }
	
	public function get_pb_by_id( $id ){
        global $wpdb;

        $sql = "SELECT * FROM {$wpdb->prefix}ays_pb WHERE id=" . absint( intval( $id ) );

        $result = $wpdb->get_row($sql, "ARRAY_A");

        return $result;
    }

    private function array_split($array, $pieces) {
        if ($pieces < 2)
            return array($array);
        $newCount = ceil(count($array)/$pieces);
        $a = array_slice($array, 0, $newCount);
        $b = $this->array_split(array_slice($array, $newCount), $pieces-1);
        return array_merge(array($a),$b);
    }
        
    private function hex2rgba( $color, $opacity = false ) {

        $default = 'rgba(39, 174, 96, 0.5)';
        /**
         * Return default if no color provided
         */
        if( empty( $color ) ) {
            return $default;
        }
        /**
         * Sanitize $color if "#" is provided
         */
        if ( $color[0] == '#' ) {
            $color = substr( $color, 1 );
        }

        /**
         * Check if color has 6 or 3 characters and get values
         */
        if ( strlen($color) == 6 ) {
            $hex = array( $color[0] . $color[1], $color[2] . $color[3], $color[4] . $color[5] );
        } elseif ( strlen( $color ) == 3 ) {
            $hex = array( $color[0] . $color[0], $color[1] . $color[1], $color[2] . $color[2] );
        } else {
            return $default;
        }

        /**
         * [$rgb description]
         * @var array
         */
        $rgb =  array_map( 'hexdec', $hex );
        /**
         * Check if opacity is set(rgba or rgb)
         */
        if( $opacity ) {
            if( abs( $opacity ) > 1 )
                $opacity = 1.0;
                $output = 'rgba( ' . implode( "," ,$rgb ) . ',' . $opacity . ' )';
        } else {
            $output = 'rgb( ' . implode( "," , $rgb ) . ' )';
        }
        /**
         * Return rgb(a) color string
         */
        return $output;
    }

}
