<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       http://ays-pro.com/
 * @since      1.0.0
 *
 * @package    Ays_Pb
 * @subpackage Ays_Pb/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Ays_Pb
 * @subpackage Ays_Pb/public/partials
 * @author     AYS Pro LLC <info@ays-pro.com>
 */
class Ays_Pb_Public_Templates {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;
    
	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
    
    public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	
	public function ays_pb_template_default( $attr ){
        $id                             = $attr["id"];
        $ays_pb_shortcode               = $attr["shortcode"];
        $ays_pb_width                   = $attr["width"];
        $ays_pb_height                  = $attr["height"];
        $ays_pb_autoclose               = $attr["autoclose"];
        $ays_pb_title           		= $attr["title"];
        $ays_pb_description     		= $attr["description"];
        $ays_pb_bgcolor					= $attr["bgcolor"];
        $ays_pb_header_bgcolor		    = $attr["header_bgcolor"];
        $ays_pb_animate_in              = $attr["animate_in"];
        $show_desc                      = $attr["show_popup_desc"];
        $show_title                     = $attr["show_popup_title"];
        $closeButton                    = $attr["close_button"];
        $ays_pb_custom_html             = $attr["custom_html"];
        $ays_pb_action_buttons_type     = $attr["action_button_type"];
        $ays_pb_modal_content           = $attr["modal_content"];
        $ays_pb_delay                   = intval($attr["delay"]);
        $ays_pb_scroll_top              = intval($attr["scroll_top"]);
        $ays_pb_textcolor               = (!isset($attr["textcolor"])) ? "#000000" : $attr["textcolor"];
        $ays_pb_bordersize              = (!isset($attr["bordersize"])) ? 0 : $attr["bordersize"];
        $ays_pb_bordercolor             = (!isset($attr["bordercolor"])) ? "#000000" : $attr["bordercolor"];
        $ays_pb_border_radius           = (!isset($attr["border_radius"])) ? "4" : $attr["border_radius"];

        $custom_class = isset($attr['custom_class']) && $attr['custom_class'] != "" ? $attr['custom_class'] : "";
        $ays_pb_bg_image				= $attr["bg_image"];
        if($ays_pb_bg_image !== ''){
            $ays_pb_bg_image = 'background-image: url('.$ays_pb_bg_image.');
                                background-repeat: no-repeat;
                                background-size: cover;
                                background-position: center center;';
        }
        if($ays_pb_title != ''  && $show_title == "On"){
            $ays_pb_title = "<h2 style='color: $ays_pb_textcolor !important;'>$ays_pb_title</h2>";
        } else {$ays_pb_title = "";}
        if($ays_pb_description != '' && $show_desc == "On"){
            $ays_pb_description = "<p>$ays_pb_description</p>";
        } else {$ays_pb_description = "";}
        if($ays_pb_action_buttons_type == 'both' || $ays_pb_action_buttons_type == 'pageLoaded'){
           if(intval($ays_pb_delay) == 0 && intval($ays_pb_scroll_top) == 0){
                $ays_pb_animate_in_open = $ays_pb_animate_in;
            }else{
                $ays_pb_animate_in_open = "";
            } 
        }
        if($ays_pb_action_buttons_type == 'clickSelector'){
            $ays_pb_animate_in_open = $ays_pb_animate_in;
        }
        if ( $closeButton == "on" ){
            $closeButton = "ays-close-button-on-off";
        } else { $closeButton = ""; }


         $popupbox_view = "
                <div class='ays-pb-modal ays-pb-modal_".$id." ".$custom_class." ".$ays_pb_animate_in_open."' style='{$ays_pb_bg_image};width: {$ays_pb_width}px; height: {$ays_pb_height}px; background-color: $ays_pb_bgcolor; color: $ays_pb_textcolor !important; border: {$ays_pb_bordersize}px solid $ays_pb_bordercolor; border-radius: {$ays_pb_border_radius}px;' >
                    <label for='ays-pb-modal-checkbox_".$id."' class='ays-pb-modal-close ".$closeButton." ays-pb-modal-close_".$id."'><i class='fa fa-times fa-2x'></i></label>
                    $ays_pb_title
                    $ays_pb_description".
             (($show_desc !== "On" && $show_title !== "On") ?  '' :  '<hr/>')
                    ."<div>".
                        (($ays_pb_modal_content == 'shortcode') ? do_shortcode($ays_pb_shortcode) : wpautop($ays_pb_custom_html))
                    ."</div>
                    <p class='ays_pb_timer ays_pb_timer_".$id."'>".__("This will close in ", $this->plugin_name)."<span data-seconds='$ays_pb_autoclose'>$ays_pb_autoclose</span>".__(" seconds", $this->plugin_name)."</p>
                </div>
            ";

			return $popupbox_view;
		}

    public function ays_pb_template_macos($attr){
        $id                             = $attr['id'];
        $ays_pb_shortcode               = $attr["shortcode"];
        $ays_pb_width                   = $attr["width"];
        $ays_pb_height                  = $attr["height"];
        $ays_pb_autoclose               = $attr["autoclose"];
        $ays_pb_title           		= $attr["title"];
        $ays_pb_description     		= $attr["description"];
        $ays_pb_bgcolor					= $attr["bgcolor"];
        $ays_pb_header_bgcolor		    = $attr["header_bgcolor"];
        $ays_pb_animate_in              = $attr["animate_in"];
        $show_desc                      = $attr["show_popup_desc"];
        $show_title                     = $attr["show_popup_title"];
        $closeButton                    = $attr["close_button"];
        $ays_pb_custom_html             = $attr["custom_html"];
        $ays_pb_action_buttons_type     = $attr["action_button_type"];
        $ays_pb_modal_content           = $attr["modal_content"];
        $ays_pb_delay                   = intval($attr["delay"]);
        $ays_pb_scroll_top              = intval($attr["scroll_top"]);
        $ays_pb_textcolor               = (!isset($attr["textcolor"])) ? "#000000" : $attr["textcolor"];
        $ays_pb_bordersize              = (!isset($attr["bordersize"])) ? 0 : $attr["bordersize"];
        $ays_pb_bordercolor             = (!isset($attr["bordercolor"])) ? "#000000" : $attr["bordercolor"];
        $ays_pb_border_radius           = (!isset($attr["border_radius"])) ? "4" : $attr["border_radius"];
        $ays_pb_bg_image				= $attr["bg_image"];

        $custom_class = isset($attr['custom_class']) && $attr['custom_class'] != "" ? $attr['custom_class'] : "";
        if($ays_pb_bg_image !== ''){
            $ays_pb_bg_image = 'background-image: url('.$ays_pb_bg_image.');
                                background-repeat: no-repeat;
                                background-size: cover;
                                background-position: center center;';
        }
        if($ays_pb_title != ''   && $show_title == "On"){
            $ays_pb_title = "<h2 style='color: $ays_pb_textcolor !important;'>$ays_pb_title</h2>";
        } else {$ays_pb_title = "";}
        if($ays_pb_description != '' && $show_desc == "On"){
            $ays_pb_description = "<p>$ays_pb_description</p>";
        } else {$ays_pb_description = "";}
        if($ays_pb_action_buttons_type == 'both' || $ays_pb_action_buttons_type == 'pageLoaded'){
           if($ays_pb_delay == 0 && $ays_pb_scroll_top == 0){
                $ays_pb_animate_in_open = $ays_pb_animate_in;
            }else{
                $ays_pb_animate_in_open = "";
            } 
        }
        if($ays_pb_action_buttons_type == 'clickSelector'){
            $ays_pb_animate_in_open = $ays_pb_animate_in;
        }

        if ( $closeButton == "on" ){
            $closeButton = "ays-close-button-on-off";
        } else { $closeButton = ""; }
        
        $mac_view = "<div class='ays_window ays-pb-modal_".$id." ".$custom_class." ".$ays_pb_animate_in_open."' style='width: {$ays_pb_width}px; height: {$ays_pb_height}px; {$ays_pb_bg_image}; background-color: $ays_pb_bgcolor; color: $ays_pb_textcolor !important; border: {$ays_pb_bordersize}px solid $ays_pb_bordercolor; border-radius: {$ays_pb_border_radius}px;'>
                         <div class='ays_topBar'>
                            <div class='".$closeButton."'>
                            <label for='ays-pb-modal-checkbox_".$id."' class='ays-pb-modal-close ays_close ays-pb-modal-close_".$id."'></label>
                            </div>
                            <div>
                            <a class='ays_hide'></a>
                            </div>
                            <div>
                            <a class='ays_fullScreen'></a>
                            </div>
                            $ays_pb_title
                         </div> 
                            $ays_pb_description                   
                         <hr/>
                         <div class='ays_text'>
                            <div class='ays_text-inner'>
                            <div class='ays_content_box'>".
								(($ays_pb_modal_content == 'shortcode') ? do_shortcode($ays_pb_shortcode) : wpautop($ays_pb_custom_html))
							."</div>
                            </div>
                         </div>                         
                         <p class='ays_pb_timer ays_pb_timer_".$id."'>".__("This will close in ", $this->plugin_name)."<span data-seconds='$ays_pb_autoclose'>$ays_pb_autoclose</span>".__(" seconds", $this->plugin_name)."</p>
                    </div>
                <script>
                (function($){
                    $('.ays_hide').on('click', function() {
                      $('.ays_window').css({
                        height: '{$ays_pb_height}px',
                        width: '{$ays_pb_width}px'
                      });
                    });

                    $('.ays_fullScreen').on('click', function() {
                      $('.ays_window').css({
                        height: '100vh',
                        width: '100vw',
                      });
                    });
                })(jQuery);
                </script>";
        return $mac_view;
    }
    
    public function ays_pb_template_cmd($attr){        
        $id                             = $attr['id'];
        $ays_pb_shortcode               = $attr["shortcode"];
        $ays_pb_width                   = $attr["width"];
        $ays_pb_height                  = $attr["height"];
        $ays_pb_autoclose               = $attr["autoclose"];
        $ays_pb_title           		= $attr["title"];
        $ays_pb_description     		= $attr["description"];
        $ays_pb_bgcolor					= $attr["bgcolor"];
        $ays_pb_header_bgcolor		    = $attr["header_bgcolor"];
        $ays_pb_animate_in              = $attr["animate_in"];
        $show_desc                      = $attr["show_popup_desc"];
        $show_title                     = $attr["show_popup_title"];
        $closeButton                    = $attr["close_button"];
        $ays_pb_custom_html             = $attr["custom_html"];
        $ays_pb_action_buttons_type     = $attr["action_button_type"];
        $ays_pb_modal_content           = $attr["modal_content"];
        $ays_pb_delay                   = intval($attr["delay"]);
        $ays_pb_scroll_top              = intval($attr["scroll_top"]);
        $ays_pb_textcolor               = (!isset($attr["textcolor"])) ? "#000000" : $attr["textcolor"];
        $ays_pb_bordersize              = (!isset($attr["bordersize"])) ? 0 : $attr["bordersize"];
        $ays_pb_bordercolor             = (!isset($attr["bordercolor"])) ? "#000000" : $attr["bordercolor"];
        $ays_pb_border_radius           = (!isset($attr["border_radius"])) ? "4" : $attr["border_radius"];
        $ays_pb_bg_image				= $attr["bg_image"];

        $custom_class = isset($attr['custom_class']) && $attr['custom_class'] != "" ? $attr['custom_class'] : "";

        if($ays_pb_bg_image !== ''){
            $ays_pb_bg_image = 'background-image: url('.$ays_pb_bg_image.');
                                background-repeat: no-repeat;
                                background-size: cover;
                                background-position: center center;';
        }
        if($ays_pb_title != ''  && $show_title == "On"){
            $ays_pb_title = "<h2 style='color: $ays_pb_textcolor !important;'>$ays_pb_title</h2>";
        } else {$ays_pb_title = "";}
        if($ays_pb_description != '' && $show_desc == "On"){
            $ays_pb_description = "<p>$ays_pb_description</p>";
        } else {$ays_pb_description = "";}
        if($ays_pb_action_buttons_type == 'both' || $ays_pb_action_buttons_type == 'pageLoaded'){
           if($ays_pb_delay == 0 && $ays_pb_scroll_top == 0){
                $ays_pb_animate_in_open = $ays_pb_animate_in;
            }else{
                $ays_pb_animate_in_open = "";
            } 
        }
        if($ays_pb_action_buttons_type == 'clickSelector'){
            $ays_pb_animate_in_open = $ays_pb_animate_in;
        }
        if ( $closeButton == "on" ){
            $closeButton = "ays-close-button-on-off";
        } else { $closeButton = ""; }
        

        $cmd_view = "<div class='ays_cmd_window ays-pb-modal_".$id." ".$custom_class." ".$ays_pb_animate_in_open."' style='width: {$ays_pb_width}px; height: {$ays_pb_height}px; background-color: $ays_pb_bgcolor; {$ays_pb_bg_image};  color: $ays_pb_textcolor !important; border: {$ays_pb_bordersize}px solid $ays_pb_bordercolor; border-radius: {$ays_pb_border_radius}px;'>
                        <header class='ays_cmd_window-header'>
                            <div class='ays_cmd_window_title'>$ays_pb_title</div>
                            <nav class='ays_cmd_window-controls'>
                                <!--<span class='ays_cmd_control-item ays_cmd_control-minimize ays_cmd_js-minimize'>‒</span>
                                <span class='ays_cmd_control-item ays_cmd_control-maximize ays_cmd_js-maximize'>□</span>
                                <label for='ays-pb-modal-checkbox_".$id."' class='ays_cmd_control-item ays_cmd_control-close ays-pb-modal-close_".$id."'><span class='ays_cmd_control-item ays_cmd_control-close ays_cmd_js-close'>˟</span></label>-->
                                <ul class='ays_cmd_window-controls-ul'>
                                    <li><span class='ays_cmd_control-item ays_cmd_control-minimize ays_cmd_js-minimize'>‒</span></li>
                                    <li><span class='ays_cmd_control-item ays_cmd_control-maximize ays_cmd_js-maximize'>□</span></li>
                                    <li><label for='ays-pb-modal-checkbox_".$id."' class='ays_cmd_control-item ".$closeButton." ays_cmd_control-close ays-pb-modal-close_".$id."'><span class='ays_cmd_control-item ays_cmd_control-close ays_cmd_js-close'>x</span></label></li>
                                </ul>
                            </nav>
                        </header>
                        <div class='ays_cmd_window-cursor'>
                            <span class='ays_cmd_i-cursor-indicator'>></span>
                            <span class='ays_cmd_i-cursor-underscore'></span>
                            <input type='text' disabled class='ays_cmd_window-input ays_cmd_js-prompt-input' />
                        </div>
                        $ays_pb_description
                        <main class='ays_cmd_window-content'>
                            <div class='ays_text'>
                                <div class='ays_text-inner'>
                                <div class='ays_content_box'>".
                                    (($ays_pb_modal_content == 'shortcode') ? do_shortcode($ays_pb_shortcode) : wpautop($ays_pb_custom_html))
                                ."</div>
                                </div>
                             </div>                         
                             <p class='ays_pb_timer ays_pb_timer_".$id."'>".__("This will close in ", $this->plugin_name)."<span data-seconds='$ays_pb_autoclose'>$ays_pb_autoclose</span>".__(" seconds", $this->plugin_name)."</p>
                        </main>
                    </div>
                    <script>
                        (function($){
                            var prompt = {
                                window: $('.ays_cmd_window'),
                                shortcut: $('.ays_cmd_prompt-shortcut'),
                                input: $('.ays_cmd_js-prompt-input'),

                                init: function() {
                                    $('.ays_cmd_js-minimize').click(prompt.minimize);
                                    $('.ays_cmd_window_title').click(prompt.minimize);
                                    $('.ays_cmd_js-maximize').click(prompt.maximize);
                                    $('.ays_cmd_js-close').click(prompt.close);
                                    $('.ays_cmd_js-open').click(prompt.open);
                                    prompt.input.focus();
                                    prompt.input.blur(prompt.focus);
                                },
                                    focus: function() {
                                    prompt.input.focus();
                                },
                                minimize: function() {        
                                    prompt.window.removeClass('ays_cmd_window--maximized');
                                    prompt.window.toggleClass('ays_cmd_window--minimized');
                                },
                                maximize: function() {
                                    prompt.window.removeClass('ays_cmd_window--minimized');
                                    prompt.window.toggleClass('ays_cmd_window--maximized');
                                    prompt.focus();
                                },
                                close: function() {
                                    prompt.window.addClass('ays_cmd_window--destroyed');
                                    prompt.window.removeClass('ays_cmd_window--maximized ays_cmd_window--minimized');
                                    prompt.shortcut.removeClass('ays_cmd_hidden');
                                    prompt.input.val('');
                                },
                                open: function() {
                                    prompt.window.removeClass('ays_cmd_window--destroyed');
                                    prompt.shortcut.addClass('ays_cmd_hidden');
                                    prompt.focus();
                                }
                            };
                            $(document).ready(prompt.init);
                        })(jQuery);
                    </script>";
        return $cmd_view;
    }   

    public function ays_pb_template_ubuntu($attr){        
        $id                             = $attr['id'];
        $ays_pb_shortcode               = $attr["shortcode"];
        $ays_pb_width                   = $attr["width"];
        $ays_pb_height                  = $attr["height"];
        $ays_pb_autoclose               = $attr["autoclose"];
        $ays_pb_title           		= $attr["title"];
        $ays_pb_description     		= $attr["description"];
        $ays_pb_bgcolor					= $attr["bgcolor"];
        $ays_pb_header_bgcolor		    = $attr["header_bgcolor"];
        $ays_pb_animate_in              = $attr["animate_in"];
        $show_desc                      = $attr["show_popup_desc"];
        $show_title                     = $attr["show_popup_title"];
        $closeButton                    = $attr["close_button"];
        $ays_pb_custom_html             = $attr["custom_html"];
        $ays_pb_action_buttons_type     = $attr["action_button_type"];
        $ays_pb_modal_content           = $attr["modal_content"];
        $ays_pb_delay                   = intval($attr["delay"]);
        $ays_pb_scroll_top              = intval($attr["scroll_top"]);
        $ays_pb_textcolor               = (!isset($attr["textcolor"])) ? "#000000" : $attr["textcolor"];
        $ays_pb_bordersize              = (!isset($attr["bordersize"])) ? 0 : $attr["bordersize"];
        $ays_pb_bordercolor             = (!isset($attr["bordercolor"])) ? "#000000" : $attr["bordercolor"];
        $ays_pb_border_radius           = (!isset($attr["border_radius"])) ? "4" : $attr["border_radius"];
        $ays_pb_bg_image				= $attr["bg_image"];

        $custom_class = isset($attr['custom_class']) && $attr['custom_class'] != "" ? $attr['custom_class'] : "";

        if($ays_pb_bg_image !== ''){
            $ays_pb_bg_image = 'background-image: url('.$ays_pb_bg_image.');
                                background-repeat: no-repeat;
                                background-size: cover;
                                background-position: center center;';
        }
        if($ays_pb_title != '' && $show_title == "On"){
            $ays_pb_title = "<h2 style='color: $ays_pb_textcolor !important;'>$ays_pb_title</h2>";
        } else {$ays_pb_title = "";}
        if($ays_pb_description != '' && $show_desc == "On"){
            $ays_pb_description = "<p>$ays_pb_description</p>";
        } else {$ays_pb_description = "";}
        if($ays_pb_action_buttons_type == 'both' || $ays_pb_action_buttons_type == 'pageLoaded'){
           if($ays_pb_delay == 0 && $ays_pb_scroll_top == 0){
                $ays_pb_animate_in_open = $ays_pb_animate_in;
            }else{
                $ays_pb_animate_in_open = "";
            } 
        }
        if($ays_pb_action_buttons_type == 'clickSelector'){
            $ays_pb_animate_in_open = $ays_pb_animate_in;
        }
        if ( $closeButton == "on" ){
            $closeButton = "ays-close-button-on-off";
        } else { $closeButton = ""; }
        
        $ubuntu_view = "<div class='ays_ubuntu_window ays-pb-modal_".$id." ".$custom_class." ".$ays_pb_animate_in_open."' style='width: {$ays_pb_width}px; height: {$ays_pb_height}px; {$ays_pb_bg_image};  background-color: $ays_pb_bgcolor; color: $ays_pb_textcolor !important; border: {$ays_pb_bordersize}px solid $ays_pb_bordercolor; border-radius: {$ays_pb_border_radius}px;'>
                      <div class='ays_ubuntu_topbar'>
                        <div class='ays_ubuntu_icons'>
                          <div class='ays_ubuntu_close  ".$closeButton."'>
                            <label for='ays-pb-modal-checkbox_".$id."' class='ays_ubuntu_close ays-pb-modal-close_".$id."'></label>
                          </div>
                          <div class='ays_ubuntu_hide'></div>
                          <div class='ays_ubuntu_maximize'></div>
                        </div>
                        $ays_pb_title
                      </div>
                      <div class='ays_ubuntu_tools'>
                        <ul>
                            <li>".__("File")."</li>
                            <li>".__("Edit", $this->plugin_name)."</li>
                            <li>".__("Go", $this->plugin_name)."</li>
                            <li>".__("Bookmarks", $this->plugin_name)."</li>
                            <li>".__("Tools", $this->plugin_name)."</li>
                            <li>".__("Help", $this->plugin_name)."</li>
                        </ul>
                      </div>
                      
                      <div class='ays_ubuntu_window_content'>
                            $ays_pb_description".
            (($show_desc !== "On") ?  '' :  '<hr/>')
                            ."<div class='ays_content_box'>".
                                (($ays_pb_modal_content == 'shortcode') ? do_shortcode($ays_pb_shortcode) : wpautop($ays_pb_custom_html))
                            ."</div>
                      </div>
                      <div class='ays_ubuntu_folder-info ays_pb_timer_".$id."'>
                        <p class='ays_pb_timer '>".__("This will close in ", $this->plugin_name)."<span data-seconds='$ays_pb_autoclose'>$ays_pb_autoclose</span>".__(" seconds", $this->plugin_name)."</p>
                      </div>
                    </div>
                    <script>
                        (function($){
                            var prompt = {
                                window: $('.ays_ubuntu_window'),

                                init: function() {
                                    $('.ays_ubuntu_hide').click(prompt.minimize);
                                    $('.ays_ubuntu_maximize').click(prompt.maximize);
                                },
                                minimize: function() {        
                                    prompt.window.removeClass('ays_ubuntu_window--maximized');
                                    prompt.window.toggleClass('ays_ubuntu_window--minimized');
                                },
                                maximize: function() {
                                    prompt.window.removeClass('ays_ubuntu_window--minimized');
                                    prompt.window.toggleClass('ays_ubuntu_window--maximized');
                                }
                            };
                            $(document).ready(prompt.init);
                        })(jQuery);
                    </script>";
        return $ubuntu_view;
    }   

    public function ays_pb_template_winxp($attr){
        $id                             = $attr['id'];
        $ays_pb_shortcode               = $attr["shortcode"];
        $ays_pb_width                   = $attr["width"];
        $ays_pb_height                  = $attr["height"];
        $ays_pb_autoclose               = $attr["autoclose"];
        $ays_pb_title           		= $attr["title"];
        $ays_pb_description     		= $attr["description"];
        $ays_pb_bgcolor					= $attr["bgcolor"];
        $ays_pb_header_bgcolor		    = $attr["header_bgcolor"];
        $ays_pb_animate_in              = $attr["animate_in"];
        $show_desc                      = $attr["show_popup_desc"];
        $show_title                     = $attr["show_popup_title"];
        $closeButton                    = $attr["close_button"];
        $ays_pb_custom_html             = $attr["custom_html"];
        $ays_pb_action_buttons_type     = $attr["action_button_type"];
        $ays_pb_modal_content           = $attr["modal_content"];
        $ays_pb_delay                   = intval($attr["delay"]);
        $ays_pb_scroll_top              = intval($attr["scroll_top"]);
        $ays_pb_textcolor               = (!isset($attr["textcolor"])) ? "#000000" : $attr["textcolor"];
        $ays_pb_bordersize              = (!isset($attr["bordersize"])) ? 0 : $attr["bordersize"];
        $ays_pb_bordercolor             = (!isset($attr["bordercolor"])) ? "#000000" : $attr["bordercolor"];
        $ays_pb_border_radius           = (!isset($attr["border_radius"])) ? "4" : $attr["border_radius"];
        $ays_pb_bg_image				= $attr["bg_image"];

        $custom_class = isset($attr['custom_class']) && $attr['custom_class'] != "" ? $attr['custom_class'] : "";

        if($ays_pb_bg_image !== ''){
            $ays_pb_bg_image = 'background-image: url('.$ays_pb_bg_image.');
                                background-repeat: no-repeat;
                                background-size: cover;
                                background-position: center center;';
        }
        if($ays_pb_title != '' && $show_title == "On"){
           // $ays_pb_title = "<h2 style='color: $ays_pb_textcolor !important;'>$ays_pb_title</h2>";
            $ays_pb_title = "<h2 style='color: white !important;'>$ays_pb_title</h2>";
        } else {$ays_pb_title = "";}
        if($ays_pb_description != '' && $show_desc == "On"){
            $ays_pb_description = "<p>$ays_pb_description</p>";
        } else {$ays_pb_description = "";}
        if($ays_pb_action_buttons_type == 'both' || $ays_pb_action_buttons_type == 'pageLoaded'){
           if($ays_pb_delay == 0 && $ays_pb_scroll_top == 0){
                $ays_pb_animate_in_open = $ays_pb_animate_in;
            }else{
                $ays_pb_animate_in_open = "";
            } 
        }
        if($ays_pb_action_buttons_type == 'clickSelector'){
            $ays_pb_animate_in_open = $ays_pb_animate_in;
        }
        if ( $closeButton == "on" ){
            $closeButton = "ays-close-button-on-off";
        } else { $closeButton = ""; }
        
        $ubuntu_view = "<div class='ays_winxp_window ays-pb-modal_".$id." ".$custom_class." ".$ays_pb_animate_in_open."' style='width: {$ays_pb_width}px; height: {$ays_pb_height}px; color: $ays_pb_textcolor !important; border: {$ays_pb_bordersize}px solid $ays_pb_bordercolor; border-radius: {$ays_pb_border_radius}px;'>
                            <div class='ays_winxp_title-bar'>
                                <div class='ays_winxp_title-bar-title'>
                                    $ays_pb_title
                                </div>
                                <div class='ays_winxp_title-bar-close ".$closeButton."'>
                                    <label for='ays-pb-modal-checkbox_".$id."' class='ays_winxp_close  ays-pb-modal-close_".$id." fas fa-times'></label>
                                </div>
                                <div class='ays_winxp_title-bar-max far fa-window-maximize fa-xs' aria-hidden='true'></div>
                                <div class='ays_winxp_title-bar-min'></div>
                            </div>
                            <div class='ays_winxp_content' style='background-color: $ays_pb_bgcolor; {$ays_pb_bg_image}; '>
                                <div>
                                    $ays_pb_description".
            (($show_title !== "On") ?  '' :  '<hr/>')
                                ."</div>
                                <div>".
                                    (($ays_pb_modal_content == 'shortcode') ? do_shortcode($ays_pb_shortcode) : wpautop($ays_pb_custom_html))
                                ."</div>
                                <p class='ays_pb_timer ays_pb_timer_".$id."'>".__("This will close in ", $this->plugin_name)."<span data-seconds='$ays_pb_autoclose'>$ays_pb_autoclose</span>".__(" seconds", $this->plugin_name)."</p>
                            </div>
                      </div>
                    <script>
                        (function($){
                            var prompt = {
                                window: $('.ays_winxp_window'),

                                init: function() {
                                    $('.ays_winxp_title-bar-min').click(prompt.minimize);
                                    $('.ays_winxp_title-bar-max').click(prompt.maximize);
                                },
                                minimize: function() {        
                                    prompt.window.removeClass('ays_winxp_window--maximized');
                                    prompt.window.toggleClass('ays_winxp_window--minimized');
                                },
                                maximize: function() {
                                    prompt.window.removeClass('ays_winxp_window--minimized');
                                    prompt.window.toggleClass('ays_winxp_window--maximized');
                                }
                            };
                            $(document).ready(prompt.init);
                        })(jQuery);
                    </script>";
        return $ubuntu_view;
    }  

    public function ays_pb_template_win98($attr){        
        $id                             = $attr['id'];
        $ays_pb_shortcode               = $attr["shortcode"];
        $ays_pb_width                   = $attr["width"];
        $ays_pb_height                  = $attr["height"];
        $ays_pb_autoclose               = $attr["autoclose"];
        $ays_pb_title           		= $attr["title"];
        $ays_pb_description     		= $attr["description"];
        $ays_pb_bgcolor					= $attr["bgcolor"];
        $ays_pb_header_bgcolor		    = $attr["header_bgcolor"];
        $ays_pb_animate_in              = $attr["animate_in"];
        $show_desc                      = $attr["show_popup_desc"];
        $show_title                     = $attr["show_popup_title"];
        $closeButton                    = $attr["close_button"];
        $ays_pb_custom_html             = $attr["custom_html"];
        $ays_pb_action_buttons_type     = $attr["action_button_type"];
        $ays_pb_modal_content           = $attr["modal_content"];
        $ays_pb_delay                   = intval($attr["delay"]);
        $ays_pb_scroll_top              = intval($attr["scroll_top"]);
        $ays_pb_textcolor               = (!isset($attr["textcolor"])) ? "#000000" : $attr["textcolor"];
        $ays_pb_bordersize              = (!isset($attr["bordersize"])) ? 0 : $attr["bordersize"];
        $ays_pb_bordercolor             = (!isset($attr["bordercolor"])) ? "#000000" : $attr["bordercolor"];
        $ays_pb_border_radius           = (!isset($attr["border_radius"])) ? "4" : $attr["border_radius"];
        $ays_pb_bg_image				= $attr["bg_image"];

        $custom_class = isset($attr['custom_class']) && $attr['custom_class'] != "" ? $attr['custom_class'] : "";

        if($ays_pb_bg_image !== ''){
            $ays_pb_bg_image = 'background-image: url('.$ays_pb_bg_image.');
                                background-repeat: no-repeat;
                                background-size: cover;
                                background-position: center center;';
        }
        if($ays_pb_title != '' && $show_title == "On"){
            $ays_pb_title = "<h2 style='color: white !important;'>$ays_pb_title</h2>";
        } else {$ays_pb_title = "";}
        if($ays_pb_description != '' && $show_desc == "On"){
            $ays_pb_description = "<p>$ays_pb_description</p>";
        } else {$ays_pb_description = "";}
        if($ays_pb_action_buttons_type == 'both' || $ays_pb_action_buttons_type == 'pageLoaded'){
           if($ays_pb_delay == 0 && $ays_pb_scroll_top == 0){
                $ays_pb_animate_in_open = $ays_pb_animate_in;
            }else{
                $ays_pb_animate_in_open = "";
            } 
        }
        if($ays_pb_action_buttons_type == 'clickSelector'){
            $ays_pb_animate_in_open = $ays_pb_animate_in;
        }
        if ( $closeButton == "on" ){
            $closeButton = "ays-close-button-on-off";
        } else { $closeButton = ""; }
        
        $ubuntu_view = "<div class='ays_win98_window ays-pb-modal_".$id." ".$custom_class." ".$ays_pb_animate_in_open."' style='width: {$ays_pb_width}px; height: {$ays_pb_height}px; background-color: $ays_pb_bgcolor; {$ays_pb_bg_image};  color: $ays_pb_textcolor !important; border: {$ays_pb_bordersize}px solid $ays_pb_bordercolor; border-radius: {$ays_pb_border_radius}px;'>
                            <header class='ays_win98_head' style='background-color: $ays_pb_bgcolor;'>
                                <div class='ays_win98_header'>
                                    <div class='ays_win98_title'>
                                        $ays_pb_title
                                    </div>
                                    <div class='ays_win98_btn-close ".$closeButton."'><label for='ays-pb-modal-checkbox_".$id."' class='ays-pb-modal-close_".$id."'><span>x</span></label></div>
                                </div>
                            </header>
                            <div class='ays_win98_main'>
                                <div class='ays_win98_content'>
                                    $ays_pb_description".
            (($show_title !== "On") ?  '' :  '<hr/>')
            ."                               
                                    <div class='ays_content_box'>".
                                        (($ays_pb_modal_content == 'shortcode') ? do_shortcode($ays_pb_shortcode) : wpautop($ays_pb_custom_html))
                                    ."</div>
                                    <p class='ays_pb_timer ays_pb_timer_".$id."'>".__("This will close in ", $this->plugin_name)."<span data-seconds='$ays_pb_autoclose'>$ays_pb_autoclose</span>".__(" seconds", $this->plugin_name)."</p>
                                </div>
                            </div>
                        </div>";
        return $ubuntu_view;
    }

    public function ays_pb_template_lil($attr){

        $id                             = $attr['id'];
        $ays_pb_shortcode               = $attr["shortcode"];
        $ays_pb_width                   = $attr["width"];
        $ays_pb_height                  = $attr["height"];
        $ays_pb_autoclose               = $attr["autoclose"];
        $ays_pb_title           		= $attr["title"];
        $ays_pb_description     		= $attr["description"];
        $ays_pb_bgcolor					= $attr["bgcolor"];
        $ays_pb_header_bgcolor		    = $attr["header_bgcolor"];
        $ays_pb_animate_in              = $attr["animate_in"];
        $show_desc                      = $attr["show_popup_desc"];
        $show_title                     = $attr["show_popup_title"];
        $closeButton                    = $attr["close_button"];
        $ays_pb_custom_html             = $attr["custom_html"];
        $ays_pb_action_buttons_type     = $attr["action_button_type"];
        $ays_pb_modal_content           = $attr["modal_content"];
        $ays_pb_delay                   = intval($attr["delay"]);
        $ays_pb_scroll_top              = intval($attr["scroll_top"]);
        $ays_pb_textcolor               = (!isset($attr["textcolor"])) ? "#000000" : $attr["textcolor"];
        $ays_pb_bordersize              = (!isset($attr["bordersize"])) ? 0 : $attr["bordersize"];
        $ays_pb_bordercolor             = (!isset($attr["bordercolor"])) ? "#000000" : $attr["bordercolor"];
        $ays_pb_border_radius           = (!isset($attr["border_radius"])) ? "4" : $attr["border_radius"];
        $ays_pb_bg_image				= $attr["bg_image"];

        $custom_class = isset($attr['custom_class']) && $attr['custom_class'] != "" ? $attr['custom_class'] : "";

        if($ays_pb_bg_image !== ''){
            $ays_pb_bg_image = 'background-image: url('.$ays_pb_bg_image.');
                                background-repeat: no-repeat;
                                background-size: cover;
                                background-position: center center;';
        }

        if($ays_pb_title != '' && $show_title == "On"){
            $ays_pb_title = "<h2 style='color: $ays_pb_textcolor !important;'>$ays_pb_title</h2>";
        } else {$ays_pb_title = "";}
        if($ays_pb_description != '' && $show_desc == "On"){
            $ays_pb_description = "<p>$ays_pb_description</p>";
        } else {$ays_pb_description = "";}
        if($ays_pb_action_buttons_type == 'both' || $ays_pb_action_buttons_type == 'pageLoaded'){
            if($ays_pb_delay == 0 && $ays_pb_scroll_top == 0){
                $ays_pb_animate_in_open = $ays_pb_animate_in;
            }else{
                $ays_pb_animate_in_open = "";
            }
        }
        if($ays_pb_action_buttons_type == 'clickSelector'){
            $ays_pb_animate_in_open = $ays_pb_animate_in;
        }
        if ( $closeButton == "on" ){
            $closeButton = "ays-close-button-on-off";
        } else { $closeButton = ""; }

        $lil_close_color = (($show_title !== "On") ?  "$ays_pb_bgcolor" :  "$ays_pb_header_bgcolor");

        $ubuntu_view = "    <div class='ays_lil_window ays-pb-modal_".$id." ".$custom_class." ".$ays_pb_animate_in_open."' style='width: {$ays_pb_width}px; height: {$ays_pb_height}px; background-color: $ays_pb_bgcolor; color: $ays_pb_textcolor !important; border: {$ays_pb_bordersize}px solid $ays_pb_bordercolor; border-radius: {$ays_pb_border_radius}px;'>
                                 <header class='ays_lil_head' style='background-color: ".(($show_title !== "On") ?  "" :  "$ays_pb_header_bgcolor").";'>
                                    <div class='ays_lil_header'>
                                        <div class='ays_lil_title'>
                                            $ays_pb_title
                                        </div>
                                        <div class='ays_lil_btn-close ".$closeButton."'><label for='ays-pb-modal-checkbox_".$id."' class='ays-pb-modal-close_".$id."' ><a class='close-lil-btn' style='background-color:".$ays_pb_textcolor." !important; color: ".$lil_close_color." ;'>x</a></label></div>
                                    </div>
                                </header>
                                <div class='ays_lil_main' style='{$ays_pb_bg_image}'>
                                    <div class='ays_lil_content'>
                                        $ays_pb_description                           
                                        <div class='ays_content_box'>".
                                        (($ays_pb_modal_content == 'shortcode') ? do_shortcode($ays_pb_shortcode) : wpautop($ays_pb_custom_html))
                                        ."</div>
                                        <p class='ays_pb_timer ays_pb_timer_".$id."'>".__("This will close in ", $this->plugin_name)."<span data-seconds='$ays_pb_autoclose'>$ays_pb_autoclose</span>".__(" seconds", $this->plugin_name)."</p>
                                    </div>
                                </div>
                            </div>";
        return $ubuntu_view;
    }

    public function ays_pb_template_image($attr){

        $id                             = $attr['id'];
        $ays_pb_shortcode               = $attr["shortcode"];
        $ays_pb_width                   = $attr["width"];
        $ays_pb_height                  = $attr["height"];
        $ays_pb_autoclose               = $attr["autoclose"];
        $ays_pb_title           		= $attr["title"];
        $ays_pb_description     		= $attr["description"];
        $ays_pb_bgcolor					= $attr["bgcolor"];
        $ays_pb_header_bgcolor		    = $attr["header_bgcolor"];
        $ays_pb_animate_in              = $attr["animate_in"];
        $show_desc                      = $attr["show_popup_desc"];
        $show_title                     = $attr["show_popup_title"];
        $closeButton                    = $attr["close_button"];
        $ays_pb_custom_html             = $attr["custom_html"];
        $ays_pb_action_buttons_type     = $attr["action_button_type"];
        $ays_pb_modal_content           = $attr["modal_content"];
        $ays_pb_delay                   = intval($attr["delay"]);
        $ays_pb_scroll_top              = intval($attr["scroll_top"]);
        $ays_pb_textcolor               = (!isset($attr["textcolor"])) ? "#000000" : $attr["textcolor"];
        $ays_pb_bordersize              = (!isset($attr["bordersize"])) ? 0 : $attr["bordersize"];
        $ays_pb_bordercolor             = (!isset($attr["bordercolor"])) ? "#000000" : $attr["bordercolor"];
        $ays_pb_border_radius           = (!isset($attr["border_radius"])) ? "4" : $attr["border_radius"];
        //$ays_pb_bg_image				= $attr["bg_image"];
        $ays_pb_bg_image                = (!isset($attr["bg_image"]))? $ays_pb_bg_image_image_default : $attr["bg_image"];

        $custom_class = isset($attr['custom_class']) && $attr['custom_class'] != "" ? $attr['custom_class'] : "";
        $ays_pb_bg_image_image_default = 'background-image: url("https://quiz-plugin.com/wp-content/uploads/2020/02/elefante.jpg");
                                background-repeat: no-repeat;
                                background-size: cover;
                                background-position: center center;';

        if($ays_pb_bg_image !== ''){
            $ays_pb_bg_image = 'background-image: url('.$ays_pb_bg_image.');
                                background-repeat: no-repeat;
                                background-size: cover;
                                background-position: center center;';
        }

        if($ays_pb_title != '' && $show_title == "On"){
            $ays_pb_title = "<h2 style='color: $ays_pb_textcolor !important;'>$ays_pb_title</h2>";
        } else {$ays_pb_title = "";}
        if($ays_pb_description != '' && $show_desc == "On"){
            $ays_pb_description = "<p>$ays_pb_description</p>";
        } else {$ays_pb_description = "";}
        if($ays_pb_action_buttons_type == 'both' || $ays_pb_action_buttons_type == 'pageLoaded'){
            if($ays_pb_delay == 0 && $ays_pb_scroll_top == 0){
                $ays_pb_animate_in_open = $ays_pb_animate_in;
            }else{
                $ays_pb_animate_in_open = "";
            }
        }
        if($ays_pb_action_buttons_type == 'clickSelector'){
            $ays_pb_animate_in_open = $ays_pb_animate_in;
        }
        if ( $closeButton == "on" ){
            $closeButton = "ays-close-button-on-off";
        } else { $closeButton = ""; }

        $image_header_height = (($show_title !== "On") ?  "height: 0% !important" :  "");
        $image_content_height = (($image_header_height !== "") ?  "max-height: 98% !important" :  "");

        $ubuntu_view = "   <div class='ays_image_window ays-pb-modal_".$id." ".$custom_class." ".$ays_pb_animate_in_open."' style='width: {$ays_pb_width}px; height: {$ays_pb_height}px; background-color: $ays_pb_bgcolor; color: $ays_pb_textcolor !important; border: {$ays_pb_bordersize}px solid $ays_pb_bordercolor; border-radius: {$ays_pb_border_radius}px; {$ays_pb_bg_image}'>
                                 <header class='ays_image_head' style='{$image_header_height}'>
                                    <div class='ays_image_header'>
                                        <div class='ays_popup_image_title'>
                                            $ays_pb_title
                                        </div>
                                        <div class='ays_image_btn-close ".$closeButton."'><label for='ays-pb-modal-checkbox_".$id."' class='ays-pb-modal-close_".$id."' ><label class='close-image-btn' style='color: ".$ays_pb_textcolor." ;'>x</label></label></div>
                                    </div>
                                </header>
                                <div class='ays_image_main' style='{$image_content_height}' >
                                    <div class='ays_image_content'>
                                        $ays_pb_description                           
                                        <div class='ays_content_box'>".
                                        (($ays_pb_modal_content == 'shortcode') ? do_shortcode($ays_pb_shortcode) : wpautop($ays_pb_custom_html))
                                        ."</div>
                                        <p class='ays_pb_timer ays_pb_timer_".$id."'>".__("This will close in ", $this->plugin_name)."<span data-seconds='$ays_pb_autoclose'>$ays_pb_autoclose</span>".__(" seconds", $this->plugin_name)."</p>
                                    </div>
                                </div>
                            </div>";
        return $ubuntu_view;
    }

    public function ays_pb_template_template($attr){

        $id                             = $attr['id'];
        $ays_pb_shortcode               = $attr["shortcode"];
        $ays_pb_width                   = $attr["width"];
        $ays_pb_height                  = $attr["height"];
        $ays_pb_autoclose               = $attr["autoclose"];
        $ays_pb_title           		= $attr["title"];
        $ays_pb_description     		= $attr["description"];
        $ays_pb_bgcolor					= $attr["bgcolor"];
        $ays_pb_header_bgcolor		    = $attr["header_bgcolor"];
        $ays_pb_animate_in              = $attr["animate_in"];
        $show_desc                      = $attr["show_popup_desc"];
        $show_title                     = $attr["show_popup_title"];
        $closeButton                    = $attr["close_button"];
        $ays_pb_custom_html             = $attr["custom_html"];
        $ays_pb_action_buttons_type     = $attr["action_button_type"];
        $ays_pb_modal_content           = $attr["modal_content"];
        $ays_pb_delay                   = intval($attr["delay"]);
        $ays_pb_scroll_top              = intval($attr["scroll_top"]);
        $ays_pb_textcolor               = (!isset($attr["textcolor"])) ? "#000000" : $attr["textcolor"];
        $ays_pb_bordersize              = (!isset($attr["bordersize"])) ? 0 : $attr["bordersize"];
        $ays_pb_bordercolor             = (!isset($attr["bordercolor"])) ? "#000000" : $attr["bordercolor"];
        $ays_pb_border_radius           = (!isset($attr["border_radius"])) ? "4" : $attr["border_radius"];
        $ays_pb_bg_image				= (!isset($attr["bg_image"]))? $ays_pb_bg_image_template_default :$attr["bg_image"];
        $custom_class = isset($attr['custom_class']) && $attr['custom_class'] != "" ? $attr['custom_class'] : "";

        $ays_pb_bg_image_template_default = 'background-image: url("https://quiz-plugin.com/wp-content/uploads/2020/02/girl-scaled.jpg");
                                background-repeat: no-repeat;
                                background-size: cover;
                                background-position: center center;';

        if($ays_pb_bg_image !== ''){
            $ays_pb_bg_image = 'background-image: url('.$ays_pb_bg_image.');
                                background-repeat: no-repeat;
                                background-size: cover;
                                background-position: center center;';
        }

        if($ays_pb_title != '' && $show_title == "On"){
            $ays_pb_title = "<h2 style='color: $ays_pb_textcolor !important;'>$ays_pb_title</h2>";
        } else {$ays_pb_title = "";}
        if($ays_pb_description != '' && $show_desc == "On"){
            $ays_pb_description = "<p>$ays_pb_description</p>";
        } else {$ays_pb_description = "";}
        if($ays_pb_action_buttons_type == 'both' || $ays_pb_action_buttons_type == 'pageLoaded'){
            if($ays_pb_delay == 0 && $ays_pb_scroll_top == 0){
                $ays_pb_animate_in_open = $ays_pb_animate_in;
            }else{
                $ays_pb_animate_in_open = "";
            }
        }
        if($ays_pb_action_buttons_type == 'clickSelector'){
            $ays_pb_animate_in_open = $ays_pb_animate_in;
        }
        if ( $closeButton == "on" ){
            $closeButton = "ays-close-button-on-off";
        } else { $closeButton = ""; }

        $header_height = (($show_title !== "On") ?  "height: 20px !important" :  "");
        $calck_template_fotter = (($show_title !== "On") ? "height: calc(100% - 20px);" :  "");

        $ubuntu_view = "   <div class='ays_template_window ays-pb-modal_".$id." ".$custom_class." ".$ays_pb_animate_in_open."' style='width: {$ays_pb_width}px; height: {$ays_pb_height}px; color: $ays_pb_textcolor !important; border: {$ays_pb_bordersize}px solid $ays_pb_bordercolor; border-radius: {$ays_pb_border_radius}px; '>
                                 <header class='ays_template_head' style='{$header_height};background-color: {$ays_pb_header_bgcolor}'>
                                    <div class='ays_template_header'>
                                        <div class='ays_template_title'>
                                            $ays_pb_title
                                        </div>
                                        <div class='ays_template_btn-close ".$closeButton."'><label for='ays-pb-modal-checkbox_".$id."' class='ays-pb-modal-close_".$id."' ><label class='close-template-btn' style='color: ".$ays_pb_textcolor." ;'>x</label></label></div>
                                    </div>
                                </header>
                                <footer class='ays_template_footer ' style='background-color: $ays_pb_bgcolor; {$calck_template_fotter} '>
                                    <div class='ays_bg_image_box' style='{$ays_pb_bg_image}'></div>
                                    <div class='ays_template_content '>
                                        $ays_pb_description 
                                        <div class='ays_content_box ays_template_main'>".
                                        (($ays_pb_modal_content == 'shortcode') ? do_shortcode($ays_pb_shortcode) : wpautop($ays_pb_custom_html))
                                        ."</div>
                                        <p class='ays_pb_timer ays_pb_timer_".$id."'><span data-seconds='$ays_pb_autoclose'>$ays_pb_autoclose</span>".__(" seconds", $this->plugin_name)."</p>                                    </div>
                                </footer>
                            </div>";
        return $ubuntu_view;
    }
}
